.. _customising-muse:

Customising MUSE Tutorials
==========================

Next, we show you how to customise MUSE to create your own scenarios.

The tutorials can be attempted in any order, but we recommend starting with the first tutorial and working your way through the list.
We have also provided links to the input and results files for each of the tutorials in the table below, should you wish to compare your results with the expected results.

.. toctree::
   :maxdepth: 1
   :hidden:

   add-solar
   additional-service-demand
   add-gdp-correlation-demand
   add-agent
   add-region
   modify-timing-data
   min-max-timeslice-constraints
   carbon-budget
   subsectors


.. list-table::
   :widths: 5 100 5
   :header-rows: 1

   *  - Tutorial
      - Description
      - Files
   *  - 1
      - :ref:`/user-guide/add-solar.ipynb`
      - `[1] <https://github.com/EnergySystemsModellingLab/MUSE_OS/tree/main/docs/tutorial-code/add-new-technology>`_
   *  - 2
      - :ref:`/user-guide/additional-service-demand.ipynb`
      - `[2] <https://github.com/EnergySystemsModellingLab/MUSE_OS/tree/main/docs/tutorial-code/add-service-demand>`_
   *  - 3
      - :ref:`/user-guide/add-gdp-correlation-demand.ipynb`
      - `[3] <https://github.com/EnergySystemsModellingLab/MUSE_OS/tree/main/docs/tutorial-code/add-correlation-demand>`_
   *  - 4
      - :ref:`/user-guide/add-agent.ipynb`
      - `[4] <https://github.com/EnergySystemsModellingLab/MUSE_OS/tree/main/docs/tutorial-code/add-agent>`_
   *  - 5
      - :ref:`/user-guide/add-region.ipynb`
      - `[5] <https://github.com/EnergySystemsModellingLab/MUSE_OS/tree/main/docs/tutorial-code/add-region>`_
   *  - 6
      - :ref:`/user-guide/modify-timing-data.ipynb`
      - `[6] <https://github.com/EnergySystemsModellingLab/MUSE_OS/tree/main/docs/tutorial-code/modify-timing-data>`_
   *  - 7
      - :ref:`/user-guide/min-max-timeslice-constraints.ipynb`
      - `[7] <https://github.com/EnergySystemsModellingLab/MUSE_OS/tree/main/docs/tutorial-code/min-max-timeslice-constraints>`_
   *  - 8
      - :ref:`/user-guide/carbon-budget.ipynb`
      - `[8] <https://github.com/EnergySystemsModellingLab/MUSE_OS/tree/main/docs/tutorial-code/carbon-budget>`_
   *  - 9
      - :ref:`/user-guide/subsectors.ipynb`
      - `[9] <https://github.com/EnergySystemsModellingLab/MUSE_OS/tree/main/docs/tutorial-code/subsectors>`_
